bypass property
This let's you define a function to be called to determine if the guard should be bypassed , useful for some reason this guard protect a parent route of your redirected route
Implementation
final Future<bool> Function(RouteMatch route, StackRouter router)? bypass;